@@ -84,7 +84,7 @@
 #define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KXMLGUI_NO_DEPRECATED
-#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
+#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
 #endif
 #ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
 #  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x56d00
+#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x56e00
 #  endif
 #endif
 
